package me.unurled.raxen.utils.libs;

import lombok.Getter;
import me.filoghost.holographicdisplays.api.HolographicDisplaysAPI;
import me.filoghost.holographicdisplays.api.hologram.Hologram;
import me.filoghost.holographicdisplays.api.hologram.line.ItemHologramLine;
import me.filoghost.holographicdisplays.api.hologram.line.TextHologramLine;
import me.unurled.raxen.Raxen;
import org.bukkit.Location;
import org.bukkit.Material;
import org.bukkit.inventory.ItemStack;
import org.bukkit.plugin.Plugin;

public class HolographicDisplay {
    private Raxen main;

    @Getter
    private HolographicDisplaysAPI holographicDisplaysAPI;

    public HolographicDisplay(Raxen main) {
        this.main = main;
        holographicDisplaysAPI = HolographicDisplaysAPI.get(main);
    }

    /**
     * create a Hologram at Loc
     * @param text the text to be displayed (one line only)
     * @param loc the location of the hologram
     * @return the created hologram
     */
    public Hologram createHologram(String text, Location loc) {
        Hologram hologram = null;
        if (text != null && !text.equals("")) {
            hologram = holographicDisplaysAPI.createHologram(loc);
            TextHologramLine textLine = hologram.getLines().appendText(text);
        }
        return hologram;
    }

    /**
     * create a Hologram at Loc
     * @param item the item to be displayed (only one)
     * @param loc the location of the hologram
     * @return the created hologram
     */
    public Hologram createHologram(ItemStack item, Location loc) {
        Hologram hologram = null;
        if (item != null && !item.getType().equals(Material.AIR)) {
            hologram = holographicDisplaysAPI.createHologram(loc);
            ItemHologramLine textLine = hologram.getLines().appendItem(item);
        }
        return hologram;
    }

    /**
     * insert in the holo
     * @param holo the hologram to insert
     * @param text the text that is inserted
     * @param line the line to change (start at 0)
     * @return the hologram
     */
    public Hologram insertHologram(Hologram holo, String text, Integer line) {
        if (text != null && !text.equals("")) {
            TextHologramLine textLine = holo.getLines().insertText(line, text);
        }
        return holo;
    }

    /**
     * insert in the holo
     * @param holo the hologram to insert
     * @param item the item that is inserted
     * @param line the line to change (start at 0)
     * @return the hologram
     */
    public Hologram insertHologram(Hologram holo, ItemStack item, Integer line) {
        if (item != null && !item.getType().equals(Material.AIR)) {
            ItemHologramLine textLine = holo.getLines().insertItem(line, item);
        }
        return holo;
    }
}
